pub struct MissingComponentError {
pub entity_description: &'static str,
pub entity: Entity,
pub component: &'static str,
}Expand description
An error that occurs when we tried to access data from an entity that it doesn’t have.
This could happen because the data does not occur for this type of entity, or because the entity is not currently loaded.
If this error happened when trying to access data on a client, then it may be because the client isn’t currently in a world.
As an alias for Result<T, MissingComponentError>, you may use
AzaleaResult. Using the eyre or anyhow crates may also simplify
error handling in your bots.
Fields
entity_description: &'static strShould be “Entity” or “Client”
entity: Entitycomponent: &'static strTrait Implementations
Sourceimpl Debug for MissingComponentError
impl Debug for MissingComponentError
Sourceimpl Display for MissingComponentError
impl Display for MissingComponentError
Sourceimpl Error for MissingComponentError
impl Error for MissingComponentError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()